@@ -18,14 +18,14 @@ sub dt_gmtime (;$) {
     $year += 1900;
 
     require DateTime;
-    return DateTime::y2038->new(
+    return perl5i::0::DateTime::y2038->new(
         year            => $year,
         month           => $mon,
         day             => $mday,
         hour            => $hour,
         minute          => $min,
         second          => $sec,
-        formatter       => "DateTime::Format::CTime"
+        formatter       => "perl5i::0::DateTime::Format::CTime"
     );
 }
 
@@ -40,7 +40,7 @@ sub dt_localtime (;$) {
     $year += 1900;
 
     require DateTime;
-    return DateTime::y2038->new(
+    return perl5i::0::DateTime::y2038->new(
         year            => $year,
         month           => $mon,
         day             => $mday,
@@ -48,7 +48,7 @@ sub dt_localtime (;$) {
         minute          => $min,
         second          => $sec,
         time_zone       => "local",
-        formatter       => "DateTime::Format::CTime"
+        formatter       => "perl5i::0::DateTime::Format::CTime"
     );
 }
 
@@ -59,7 +59,7 @@ sub dt_time () {
     state $formatter = DateTime::Format::Epoch->new( epoch => DateTime->from_epoch( epoch => 0 ) );
 
     require DateTime;
-    return DateTime::time->from_epoch(
+    return perl5i::0::DateTime::time->from_epoch(
         epoch     => time,
         formatter => $formatter
     );
@@ -67,7 +67,7 @@ sub dt_time () {
 
 
 {
-    package DateTime::y2038;
+    package perl5i::0::DateTime::y2038;
 
     # Don't load DateTime until we need it.
     our @ISA = qw(DateTime);
@@ -113,9 +113,9 @@ sub dt_time () {
 
 {
 
-    package DateTime::time;
+    package perl5i::0::DateTime::time;
 
-    use parent -norequire, qw(DateTime::y2038);
+    use parent -norequire, qw(perl5i::0::DateTime::y2038);
 
     use overload
       "0+" => sub { $_[0]->epoch },
@@ -157,7 +157,7 @@ sub dt_time () {
 
 {
 
-    package DateTime::Format::CTime;
+    package perl5i::0::DateTime::Format::CTime;
 
     use CLASS;
 
