@@ -127,14 +127,18 @@ ERROR
 }
 
 
-use POSIX qw{ceil floor};
-sub SCALAR::ceil  { ceil($_[0]) }
-sub SCALAR::floor { floor($_[0])}
+require POSIX;
+*SCALAR::ceil  = \&POSIX::ceil;
+*SCALAR::floor = \&POSIX::floor;
 *SCALAR::round_up   = \&SCALAR::ceil;
 *SCALAR::round_down = \&SCALAR::floor;
+sub SCALAR::round {
+    abs($_[0] - int($_[0])) < 0.5 ? SCALAR::round_down($_[0])
+                                  : SCALAR::round_up($_[0])
+}
 
-use Scalar::Util qw(looks_like_number);
-sub SCALAR::is_number           { looks_like_number($_[0]) }
+require Scalar::Util;
+*SCALAR::is_number = \&Scalar::Util::looks_like_number;
 sub SCALAR::is_positive         { $_[0]->is_number && $_[0] > 0 }
 sub SCALAR::is_negative         { $_[0]->is_number && $_[0] < 0 }
 sub SCALAR::is_integer          { $_[0]->is_number && ((int($_[0]) - $_[0]) == 0) }
