@@ -5,7 +5,9 @@ use warnings;
 # This is the sub that displays the message
 my $diesub = sub {
     my ( $sub, $mod ) = @_;
-    return if $^H{perl5i};
+
+    my $hints = (caller(0))[10];
+    return unless $hints->{perl5i};
     die( <<EOT );
 Can't locate $mod in your Perl library.  You may need to install it
 from CPAN or another repository.  Your library paths are:
@@ -13,7 +15,7 @@ from CPAN or another repository.  Your library paths are:
 EOT
 };
 
-# This sub makes sure the die sub si always at the end of @INC.
+# This sub makes sure the die sub is always at the end of @INC.
 push @INC => sub {
     return if ref($INC[-1]) && $INC[-1] == $diesub;
     @INC = grep { !(ref($_) && $_ == $diesub) } @INC;
